pub struct AffectedNode {
pub node_id: NodeId,
pub node_info: NodeInfo,
pub severity: ImpactSeverity,
pub hop_distance: usize,
pub entry_edge: EdgeKind,
pub direction: ImpactDirection,
}Expand description
A node affected by a change to the target.
Fields
node_id: NodeIdThe node’s graph index.
node_info: NodeInfoFull node information.
severity: ImpactSeveritySeverity derived from hop distance.
hop_distance: usizeNumber of edges from target to this node.
entry_edge: EdgeKindThe edge kind of the first hop that led to this node. This explains why this node is in the impact set.
direction: ImpactDirectionWhether this node is upstream or downstream of target.